@@ -150,29 +150,22 @@ namespace evalhyd
                             auto obs_filtered =
                                     xt::filter(obs, !xt::isnan(obs));
 
-                            // -------------------------------------------------
-                            // TODO: use `xt::argsort` with `xt::sorting_method::stable`
-                            //       when this becomes possible with `xtensor` to
-                            //       consistently sort ties across compilers
-                            //       https://github.com/xtensor-stack/xtensor/issues/2677
-                            //       note that the second sorting (to get the
-                            //       rank) does not need the stable method
-                            //       because there will be no ties after the
-                            //       first sorting
-                            auto prd_sort = xt::argsort(xt::eval(prd_filtered));
-                            auto obs_sort = xt::argsort(xt::eval(obs_filtered));
-                            // -------------------------------------------------
+                            auto prd_sort = xt::argsort(
+                                    xt::eval(prd_filtered), {0},
+                                    xt::sorting_method::stable
+                            );
+                            auto obs_sort = xt::argsort(
+                                    xt::eval(obs_filtered), {0},
+                                    xt::sorting_method::stable
+                            );
 
                             auto prd_rank = xt::eval(xt::argsort(prd_sort));
                             auto obs_rank = xt::eval(xt::argsort(obs_sort));
 
-                            auto mean_prd_rank =
-                                    xt::eval(xt::nanmean(prd_rank));
-                            auto mean_obs_rank =
-                                    xt::eval(xt::nanmean(obs_rank));
+                            auto mean_rank = (prd_rank.size() - 1) / 2.;
 
-                            auto prd_rank_err = xt::eval(prd_rank - mean_prd_rank);
-                            auto obs_rank_err = xt::eval(obs_rank - mean_obs_rank);
+                            auto prd_rank_err = xt::eval(prd_rank - mean_rank);
+                            auto obs_rank_err = xt::eval(obs_rank - mean_rank);
 
                             auto r_num = xt::nansum(prd_rank_err * obs_rank_err);
 
