@@ -35,7 +35,10 @@ namespace evalhyd
             // observed or predicted (median or mean for probabilist) streamflow
             // e.g. q{>9.} q{<9} q{>=99.0} q{<=99} q{>9,<99} q{==9} q{!=9}
             std::regex exp_q (
-                    R"((q_obs|q_prd_median|q_prd_mean)\{(((<|>|<=|>=|==|!=)(mean,?|median,?|qtl[0-1]\.[0-9]+,?|[0-9]+\.?[0-9]*,?))+)\})"
+                    R"((q_obs|q_prd_median|q_prd_mean)\{(((<|>|<=|>=|==|!=)(mean,?|median,?|qtl(0|1)\.(0|1|2|3|4|5|6|7|8|9)+,?|(0|1|2|3|4|5|6|7|8|9)+\.?(0|1|2|3|4|5|6|7|8|9)*,?))+)\})"
+                    // NOTE: this should be `R"((q_obs|q_prd_median|q_prd_mean)\{(((<|>|<=|>=|==|!=)(mean,?|median,?|qtl[0-1]\.[0-9]+,?|[0-9]+\.?[0-9]*,?))+)\})"`
+                    //       but there is a bug in the building chain for R packages
+                    //       https://gitlab.irstea.fr/HYCAR-Hydro/evalhyd/evalhyd-r/-/issues/6
             );
 
             for (std::sregex_iterator i =
@@ -51,7 +54,12 @@ namespace evalhyd
                 std::vector<std::vector<std::string>> conditions;
 
                 // pattern supported to specify masking conditions based on streamflow
-                std::regex ex (R"((<|>|<=|>=|==|!=)(mean|median|qtl[0-1]\.[0-9]+|[0-9]+\.?[0-9]*))");
+                std::regex ex (
+                        R"((<|>|<=|>=|==|!=)(mean|median|qtl(0|1)\.(0|1|2|3|4|5|6|7|8|9)+|(0|1|2|3|4|5|6|7|8|9)+\.?(0|1|2|3|4|5|6|7|8|9)*))"
+                        // NOTE: this should be `R"((<|>|<=|>=|==|!=)(mean|median|qtl[0-1]\.[0-9]+|[0-9]+\.?[0-9]*))"`
+                        //       but there is a bug in the building chain for R packages
+                        //       https://gitlab.irstea.fr/HYCAR-Hydro/evalhyd/evalhyd-r/-/issues/6
+                );
 
                 for (std::sregex_iterator j =
                         std::sregex_iterator(str.begin(), str.end(), ex);
@@ -92,7 +100,12 @@ namespace evalhyd
 
             // pattern supported to specify conditions to generate masks on time index
             // e.g. t{0:10} t{0:10,20:30} t{0,1,2,3} t{0:10,30,40,50} t{:}
-            std::regex exp_t (R"((t)\{(:|([0-9]+:[0-9]+,?|[0-9]+,?)+)\})");
+            std::regex exp_t (
+                    R"((t)\{(:|((0|1|2|3|4|5|6|7|8|9)+:(0|1|2|3|4|5|6|7|8|9)+,?|(0|1|2|3|4|5|6|7|8|9)+,?)+)\})"
+                    // NOTE: this should be `R"((t)\{(:|([0-9]+:[0-9]+,?|[0-9]+,?)+)\})"`
+                    //       but there is a bug in the building chain for R packages
+                    //       https://gitlab.irstea.fr/HYCAR-Hydro/evalhyd/evalhyd-r/-/issues/6
+            );
 
             for (std::sregex_iterator i =
                     std::sregex_iterator(msk_str.begin(), msk_str.end(), exp_t);
@@ -114,7 +127,12 @@ namespace evalhyd
                 else
                 {
                     // pattern supported to specify masking conditions based on time index
-                    std::regex e (R"([0-9]+:[0-9]+|[0-9]+)");
+                    std::regex e (
+                            R"((0|1|2|3|4|5|6|7|8|9)+:(0|1|2|3|4|5|6|7|8|9)+|(0|1|2|3|4|5|6|7|8|9)+)"
+                            // NOTE: this should be `R"([0-9]+:[0-9]+|[0-9]+)"`
+                            //       but there is a bug in the building chain for R packages
+                            //       https://gitlab.irstea.fr/HYCAR-Hydro/evalhyd/evalhyd-r/-/issues/6
+                    );
 
                     for (std::sregex_iterator j =
                             std::sregex_iterator(s.begin(), s.end(), e);
@@ -232,17 +250,29 @@ namespace evalhyd
                         {
                             return std::stod(num);
                         }
-                        else if (str == "median")
+                        else
                         {
-                            return xt::median(q);
-                        }
-                        else if (str == "mean")
-                        {
-                            return xt::mean(q)();
-                        }
-                        else  // (str == "qtl")
-                        {
-                            return xt::quantile(q, {std::stod(num)})();
+                            auto q_filtered = xt::filter(q, !xt::isnan(q));
+
+                            if (q_filtered.size() > 0)
+                            {
+                                if (str == "median")
+                                {
+                                    return xt::median(q_filtered);
+                                }
+                                else if (str == "mean")
+                                {
+                                    return xt::mean(q_filtered)();
+                                }
+                                else  // (str == "qtl")
+                                {
+                                    return xt::quantile(q_filtered, {std::stod(num)})();
+                                }
+                            }
+                            else
+                            {
+                                return double(NAN);
+                            }
                         }
                     };
 
