@@ -297,6 +297,84 @@ namespace evalhyd
                 }
             }
 
+            /// Compute the contingency table (CONT_TBL), i.e. 'hits',
+            /// 'false alarms', 'misses', 'correct rejections', in this order.
+            ///
+            /// \param ct_a
+            ///     Hits.
+            ///     shape: (sites, lead times, levels, thresholds, time)
+            /// \param ct_b
+            ///     False alarms.
+            ///     shape: (sites, lead times, levels, thresholds, time)
+            /// \param ct_c
+            ///     Misses.
+            ///     shape: (sites, lead times, levels, thresholds, time)
+            /// \param ct_d
+            ///     Correct rejections.
+            ///     shape: (sites, lead times, levels, thresholds, time)
+            /// \param q_thr
+            ///     Streamflow exceedance threshold(s).
+            ///     shape: (sites, thresholds)
+            /// \param t_msk
+            ///     Temporal subsets of the whole record.
+            ///     shape: (sites, lead times, subsets, time)
+            /// \param b_exp
+            ///     Boostrap samples.
+            ///     shape: (samples, time slice)
+            /// \param n_sit
+            ///     Number of sites.
+            /// \param n_ldt
+            ///     Number of lead times.
+            /// \param n_thr
+            ///     Number of thresholds.
+            /// \param n_mbr
+            ///     Number of ensemble members.
+            /// \param n_msk
+            ///     Number of temporal subsets.
+            /// \param n_exp
+            ///     Number of bootstrap samples.
+            /// \return
+            ///     Contingency table.
+            ///     shape: (sites, lead times, subsets, samples, levels, thresholds, cells)
+            template <class XD2>
+            inline xt::xtensor<double, 7> calc_CONT_TBL(
+                    const xt::xtensor<double, 5>& ct_a,
+                    const xt::xtensor<double, 5>& ct_b,
+                    const xt::xtensor<double, 5>& ct_c,
+                    const xt::xtensor<double, 5>& ct_d,
+                    const XD2& q_thr,
+                    const xt::xtensor<bool, 4>& t_msk,
+                    const std::vector<xt::xkeep_slice<int>>& b_exp,
+                    std::size_t n_sit,
+                    std::size_t n_ldt,
+                    std::size_t n_thr,
+                    std::size_t n_mbr,
+                    std::size_t n_msk,
+                    std::size_t n_exp
+            )
+            {
+                // initialise output variable
+                xt::xtensor<double, 7> CONT_TBL =
+                        xt::zeros<double>({n_sit, n_ldt, n_msk, n_exp,
+                                           n_mbr + 1, n_thr, std::size_t {4}});
+
+                // compute table one cell at a time
+                std::size_t i = 0;
+                for (auto cell: {ct_a, ct_b, ct_c, ct_d})
+                {
+                    xt::view(CONT_TBL, xt::all(), xt::all(), xt::all(),
+                             xt::all(), xt::all(), xt::all(), i) =
+                        detail::calc_METRIC_from_metric(
+                                cell, q_thr, t_msk, b_exp,
+                                n_sit, n_ldt, n_thr, n_mbr, n_msk, n_exp
+                        );
+
+                    i++;
+                }
+
+                return CONT_TBL;
+            }
+
             /// Compute the probability of detection (POD),
             /// also known as 'hit rate'.
             ///
