@@ -110,6 +110,7 @@ namespace evalhyd
             xtl::xoptional<xt::xtensor<double, 5>, bool> QS;
             xtl::xoptional<xt::xtensor<double, 4>, bool> CRPS_FROM_QS;
             // > Contingency table-based
+            xtl::xoptional<xt::xtensor<double, 7>, bool> CONT_TBL;
             xtl::xoptional<xt::xtensor<double, 6>, bool> POD;
             xtl::xoptional<xt::xtensor<double, 6>, bool> POFD;
             xtl::xoptional<xt::xtensor<double, 6>, bool> FAR;
@@ -651,6 +652,19 @@ namespace evalhyd
                 return CRPS_FROM_QS.value();
             };
 
+            xt::xtensor<double, 7> get_CONT_TBL()
+            {
+                if (!CONT_TBL.has_value())
+                {
+                    CONT_TBL = metrics::calc_CONT_TBL(
+                            get_ct_a(), get_ct_b(), get_ct_c(), get_ct_d(),
+                            get_q_thr(), t_msk, b_exp,
+                            n_sit, n_ldt, n_thr, n_mbr, n_msk, n_exp
+                    );
+                }
+                return CONT_TBL.value();
+            };
+
             xt::xtensor<double, 6> get_POD()
             {
                 if (!POD.has_value())
