@@ -123,119 +123,6 @@ namespace evalhyd
 
                 return (u - l);
             }
-
-            /// Compute the bounds of the climatology corresponding to the
-            /// confidence levels.
-            ///
-            /// \param q_obs
-            ///     Streamflow predictions.
-            ///     shape: (sites, time)
-            /// \param c_lvl
-            ///     Confidence levels for the predictive intervals.
-            ///     shape: (intervals,)
-            /// \param t_msk
-            ///     Temporal subsets of the whole record.
-            ///     shape: (sites, lead times, subsets, time)
-            /// \param b_exp
-            ///     Boostrap samples.
-            ///     shape: (samples, time slice)
-            /// \param n_sit
-            ///     Number of sites.
-            /// \param n_ldt
-            ///     Number of lead times.
-            /// \param n_itv
-            ///     Number of predictive intervals.
-            /// \param n_msk
-            ///     Number of temporal subsets.
-            /// \param n_exp
-            ///     Number of bootstrap samples.
-            /// \return
-            ///     Climatology bounds.
-            ///     shape: (sites, lead times, subsets, samples, intervals, bounds)
-            template <class XD2>
-            inline xt::xtensor<double, 6> calc_clim_bnds(
-                    const XD2& q_obs,
-                    const xt::xtensor<double, 1>& c_lvl,
-                    const xt::xtensor<bool, 4>& t_msk,
-                    const std::vector<xt::xkeep_slice<int>>& b_exp,
-                    std::size_t n_sit,
-                    std::size_t n_ldt,
-                    std::size_t n_itv,
-                    std::size_t n_msk,
-                    std::size_t n_exp
-            )
-            {
-                // compute "climatology" average width
-                xt::xtensor<double, 6> clim_bnds =
-                        xt::zeros<double>({n_sit, n_ldt, n_msk, n_exp,
-                                           n_itv, std::size_t {2}});
-
-                // determine quantiles forming the predictive intervals
-                // from the confidence levels
-                xt::xtensor<double, 2> quantiles =
-                        xt::zeros<double>({n_itv, std::size_t {2}});
-                xt::col(quantiles, 0) = 0.5 - c_lvl / 200.;
-                xt::col(quantiles, 1) = 0.5 + c_lvl / 200.;
-
-                // compute variable one mask at a time to minimise memory imprint
-                for (std::size_t m = 0; m < n_msk; m++)
-                {
-                    // apply the mask
-                    // (using NaN workaround until reducers work on masked_view)
-                    auto q_obs_masked = xt::where(
-                            xt::view(t_msk, xt::all(), xt::all(), m, xt::all()),
-                            xt::view(q_obs, xt::all(), xt::newaxis(), xt::all()),
-                            NAN
-                    );
-
-                    // compute variable one sample at a time
-                    for (std::size_t e = 0; e < n_exp; e++)
-                    {
-                        // apply the bootstrap sampling
-                        auto q_obs_masked_sampled =
-                                xt::view(q_obs_masked, xt::all(), xt::all(), b_exp[e]);
-
-                        // compute "climatology" interval
-                        for (std::size_t s = 0; s < n_sit; s++)
-                        {
-                            for (std::size_t l = 0; l < n_ldt; l++)
-                            {
-                                for (std::size_t i = 0; i < n_itv; i++)
-                                {
-                                    auto obs = xt::view(q_obs_masked_sampled,
-                                                        s, l, xt::all());
-                                    auto obs_filtered =
-                                            xt::filter(obs, !xt::isnan(obs));
-
-                                    if (obs_filtered.size() > 0)
-                                    {
-                                        // lower bound
-                                        xt::view(clim_bnds, s, l, m, e, i, 0) =
-                                                xt::quantile(
-                                                        obs_filtered,
-                                                        {quantiles(i, 0)}
-                                                )();
-                                        // upper bound
-                                        xt::view(clim_bnds, s, l, m, e, i, 1) =
-                                                xt::quantile(
-                                                        obs_filtered,
-                                                        {quantiles(i, 1)}
-                                                )();
-                                    }
-                                    else
-                                    {
-                                        xt::view(clim_bnds, s, l, m, e, i, xt::all()) =
-                                                NAN;
-                                    }
-
-                                }
-                            }
-                        }
-                    }
-                }
-
-                return clim_bnds;
-            }
         }
 
         namespace intermediate
@@ -487,34 +374,6 @@ namespace evalhyd
                                  - std::numeric_limits<double>::infinity());
             }
 
-            /// Compute the Average Width Index (AWI).
-            ///
-            /// \param AW
-            ///     Average widths.
-            ///     shape: (sites, lead times, subsets, samples, intervals)
-            /// \param clim_bnds
-            ///     Climatology bounds.
-            ///     shape: (sites, lead times, subsets, samples, intervals, bounds)
-            /// \return
-            ///     Average width indices.
-            ///     shape: (sites, lead times, subsets, samples, intervals)
-            inline xt::xtensor<double, 5> calc_AWI(
-                    const xt::xtensor<double, 5>& AW,
-                    const xt::xtensor<double, 6>& clim_bnds
-            )
-            {
-                // compute "climatology" average width
-                auto AW_clim =
-                        xt::view(clim_bnds, xt::all(), xt::all(), xt::all(),
-                                 xt::all(), xt::all(), 1)
-                        - xt::view(clim_bnds, xt::all(), xt::all(), xt::all(),
-                                   xt::all(), xt::all(), 0);
-
-                return xt::where(AW_clim > 0,
-                                 1 - (AW / AW_clim),
-                                 - std::numeric_limits<double>::infinity());
-            }
-
             /// Compute the Winkler scores (WS), also known as interval score.
             ///
             /// \param ws
@@ -554,95 +413,6 @@ namespace evalhyd
                         ws, t_msk, b_exp, n_sit, n_ldt, n_itv, n_msk, n_exp
                 );
             }
-
-            /// Compute the Winkler skill scores (WSS).
-            ///
-            /// \param q_obs
-            ///     Streamflow predictions.
-            ///     shape: (sites, time)
-            /// \param c_lvl
-            ///     Confidence levels for the predictive intervals.
-            ///     shape: (intervals,)
-            /// \param clim_bnds
-            ///     Climatology bounds.
-            ///     shape: (sites, lead times, subsets, samples, intervals, bounds)
-            /// \param WS
-            ///     Winkler scores.
-            ///     shape: (sites, lead times, subsets, samples, intervals)
-            /// \param t_msk
-            ///     Temporal subsets of the whole record.
-            ///     shape: (sites, lead times, subsets, time)
-            /// \param b_exp
-            ///     Boostrap samples.
-            ///     shape: (samples, time slice)
-            /// \param n_sit
-            ///     Number of sites.
-            /// \param n_ldt
-            ///     Number of lead times.
-            /// \param n_itv
-            ///     Number of predictive intervals.
-            /// \param n_msk
-            ///     Number of temporal subsets.
-            /// \param n_exp
-            ///     Number of bootstrap samples.
-            /// \return
-            ///     Winkler skill scores.
-            ///     shape: (sites, lead times, subsets, samples, intervals)
-            template <class XD2>
-            inline xt::xtensor<double, 5> calc_WSS(
-                    const XD2& q_obs,
-                    const xt::xtensor<double, 1>& c_lvl,
-                    const xt::xtensor<double, 6>& clim_bnds,
-                    const xt::xtensor<double, 5>& WS,
-                    const xt::xtensor<bool, 4>& t_msk,
-                    const std::vector<xt::xkeep_slice<int>>& b_exp,
-                    std::size_t n_sit,
-                    std::size_t n_ldt,
-                    std::size_t n_itv,
-                    std::size_t n_msk,
-                    std::size_t n_exp
-            )
-            {
-                // compute "climatology" Winkler score
-                xt::xtensor<double, 5> WS_clim =
-                        xt::zeros<double>({n_sit, n_ldt, n_msk, n_exp, n_itv});
-
-                for (std::size_t l = 0; l < n_ldt; l++)
-                {
-                    for (std::size_t m = 0; m < n_msk; m++)
-                    {
-                        for (std::size_t e = 0; e < n_exp; e++)
-                        {
-                            auto ws_clim = intermediate::calc_ws(
-                                    q_obs, c_lvl,
-                                    xt::view(clim_bnds, xt::all(), l, xt::newaxis(),
-                                             m, e, xt::all(), xt::all(),
-                                             xt::newaxis())
-                            );
-
-                            // apply the mask
-                            // (using NaN workaround until reducers work on masked_view)
-                            auto ws_clim_masked = xt::where(
-                                    xt::view(t_msk, xt::all(), l, m, xt::newaxis(), xt::all()),
-                                    xt::view(ws_clim, xt::all(), l, xt::all(), xt::all()),
-                                    NAN
-                            );
-
-                            // apply the bootstrap sampling
-                            auto ws_clim_masked_sampled =
-                                    xt::view(ws_clim_masked, xt::all(), xt::all(), b_exp[e]);
-
-                            xt::view(WS_clim, xt::all(), l, m, e, xt::all()) =
-                                    xt::nanmean(ws_clim_masked_sampled, -1);
-                        }
-                    }
-                }
-
-                // compute the Winkler skill score
-                return xt::where(WS_clim > 0,
-                                 1 - (WS / WS_clim),
-                                 - std::numeric_limits<double>::infinity());
-            }
         }
     }
 }
