@@ -105,8 +105,41 @@ namespace evalhyd
                         (x_timepoints >= start) && (x_timepoints < end);
 
                 // check that year is complete (without a rigorous leap year check)
-                int n_days = xt::sum(wdw)();
-                if ((n_days != 365) && (n_days != 366))
+                bool complete_yr = true;
+                if (std::chrono::minutes(ti).count() == 1)
+                {
+                    // minute timestep
+                    int n_minutes = xt::sum(wdw)();
+                    if ((n_minutes != 60 * 24 * 365) && (n_minutes != 60 * 24 * 366))
+                    {
+                        complete_yr = false;
+                    }
+                }
+                else if (std::chrono::minutes(ti).count() == 60)
+                {
+                    // hourly timestep
+                    int n_hours = xt::sum(wdw)();
+                    if ((n_hours != 24 * 365) && (n_hours != 24 * 366))
+                    {
+                        complete_yr = false;
+                    }
+                }
+                else if (std::chrono::minutes(ti).count() == 60 * 24)
+                {
+                    // daily timestep
+                    int n_days = xt::sum(wdw)();
+                    if ((n_days != 365) && (n_days != 366))
+                    {
+                        complete_yr = false;
+                    }
+                }
+                else
+                {
+                    throw std::runtime_error(
+                            "time step must be minute, hourly, or daily"
+                    );
+                }
+                if (!complete_yr)
                 {
                     throw std::runtime_error(
                             "year starting in " + std::to_string(y - 400)
