@@ -132,7 +132,9 @@ namespace evalhyd
     ///       The date and time must be specified in a string following the
     ///       ISO 8601-1:2019 standard, i.e. "YYYY-MM-DD hh:mm:ss" (e.g. the
     ///       21st of May 2007 at 4 in the afternoon is "2007-05-21 16:00:00").
-    ///       If provided, it is only used if *bootstrap* is also provided.
+    ///       The time series must feature complete years. Only minute, hourly,
+    ///       and daily time steps are supported. If provided, it is only used
+    ///       if *bootstrap* is also provided.
     ///
     ///    seed: ``int``, optional
     ///       A value for the seed used by random generators. This parameter
@@ -244,13 +246,7 @@ namespace evalhyd
                 metrics,
                 {"MAE", "MARE", "MSE", "RMSE",
                  "NSE", "KGE", "KGE_D", "KGEPRIME", "KGEPRIME_D",
-                 // ------------------------------------------------------------
-                 // TODO: bring back when `xt::argsort` supports stable sorting
-                 //       so that the r_spearman component of KGENP and KGENP_D
-                 //       yields consistent results across compilers
-                 //       https://github.com/xtensor-stack/xtensor/issues/2677
-                 // "KGENP", "KGENP_D",
-                 // ------------------------------------------------------------
+                 "KGENP", "KGENP_D",
                  "CONT_TBL"}
         );
 
@@ -391,7 +387,7 @@ namespace evalhyd
                     if ( !epsilon.has_value() )
                     {
                         // determine an epsilon value to avoid zero divide
-                        epsilon = xt::mean(q_obs_)() * 0.01;
+                        epsilon = xt::nanmean(q_obs_)() * 0.01;
                     }
 
                     return XD2(1. / (q + epsilon.value()));
@@ -401,7 +397,7 @@ namespace evalhyd
                     if ( !epsilon.has_value() )
                     {
                         // determine an epsilon value to avoid log zero
-                        epsilon = xt::mean(q_obs_)() * 0.01;
+                        epsilon = xt::nanmean(q_obs_)() * 0.01;
                     }
 
                     return XD2(xt::log(q + epsilon.value()));
@@ -419,7 +415,7 @@ namespace evalhyd
                             if ( !epsilon.has_value() )
                             {
                                 // determine an epsilon value to avoid zero divide
-                                epsilon = xt::mean(q_obs_)() * 0.01;
+                                epsilon = xt::nanmean(q_obs_)() * 0.01;
                             }
 
                             return XD2(xt::pow(q + epsilon.value(),
