@@ -123,7 +123,9 @@ namespace evalhyd
     ///       The date and time must be specified in a string following the
     ///       ISO 8601-1:2019 standard, i.e. "YYYY-MM-DD hh:mm:ss" (e.g. the
     ///       21st of May 2007 at 4 in the afternoon is "2007-05-21 16:00:00").
-    ///       If provided, it is only used if *bootstrap* is also provided.
+    ///       The time series must feature complete years. Only minute, hourly,
+    ///       and daily time steps are supported. If provided, it is only used
+    ///       if *bootstrap* is also provided.
     ///
     ///    seed: ``int``, optional
     ///       A value for the seed used by random generators. This parameter
@@ -238,7 +240,7 @@ namespace evalhyd
                 {"BS", "BSS", "BS_CRD", "BS_LBD", "REL_DIAG", "CRPS_FROM_BS",
                  "CRPS_FROM_ECDF",
                  "QS", "CRPS_FROM_QS",
-                 "POD", "POFD", "FAR", "CSI", "ROCSS",
+                 "CONT_TBL", "POD", "POFD", "FAR", "CSI", "ROCSS",
                  "RANK_HIST", "DS", "AS",
                  "CR", "AW", "AWN", "WS",
                  "ES"}
@@ -481,6 +483,12 @@ namespace evalhyd
                         uncertainty::summarise_p(evaluator.get_CRPS_FROM_QS(), summary)
                 );
             }
+            else if ( metric == "CONT_TBL" )
+            {
+                r.emplace_back(
+                        uncertainty::summarise_p(evaluator.get_CONT_TBL(), summary)
+                );
+            }
             else if ( metric == "POD" )
             {
                 r.emplace_back(
