@@ -31,13 +31,7 @@ using namespace xt::placeholders;  // required for `_` to work
 std::vector<std::string> all_metrics_d = {
         "MAE", "MARE", "MSE", "RMSE",
         "NSE", "KGE", "KGE_D", "KGEPRIME", "KGEPRIME_D",
-        // ---------------------------------------------------------------------
-        // TODO: bring back when `xt::argsort` supports stable sorting
-        //       so that the r_spearman component of KGENP and KGENP_D
-        //       yields consistent results across compilers
-        //       https://github.com/xtensor-stack/xtensor/issues/2677
-        // "KGENP", "KGENP_D",
-        // ---------------------------------------------------------------------
+        "KGENP", "KGENP_D",
         "CONT_TBL"
 };
 
@@ -46,7 +40,7 @@ std::tuple<xt::xtensor<double, 2>, xt::xtensor<double, 2>> load_data_d()
     // read in data
     std::ifstream ifs;
     ifs.open(EVALHYD_DATA_DIR "/data/q_obs.csv");
-    xt::xtensor<double, 2> observed = xt::load_csv<int>(ifs);
+    xt::xtensor<double, 2> observed = xt::load_csv<double>(ifs);
     ifs.close();
 
     ifs.open(EVALHYD_DATA_DIR "/data/q_prd.csv");
@@ -148,7 +142,7 @@ TEST(DeterministTests, TestTransform)
             evalhyd::evald(observed, predicted, all_metrics_d,
                            thresholds, "high", "inv");
 
-    xt::xtensor<double, 2> epsilon = xt::mean(observed, {1}, xt::keep_dims) * 0.01;
+    xt::xtensor<double, 2> epsilon = xt::nanmean(observed, {1}, xt::keep_dims) * 0.01;
     xt::xtensor<double, 2> obs_inv = 1. / (observed + epsilon);
     xt::xtensor<double, 2> prd_inv = 1. / (predicted + epsilon);
     xt::xtensor<double, 2> thr_inv = 1. / (thresholds + epsilon);
@@ -308,7 +302,7 @@ TEST(DeterministTests, TestMaskingConditions)
     };
     q_conditions_ = xt::repeat(q_conditions_, predicted.shape(0), 0);
 
-    double mean = xt::mean(observed, {1})();
+    double mean = xt::nanmean(observed, {1})();
 
     std::vector<xt::xarray<double>> metrics_q_conditioned_ =
             evalhyd::evald(
