@@ -33,7 +33,7 @@ std::vector<std::string> all_metrics_p = {
         "BS", "BSS", "BS_CRD", "BS_LBD", "REL_DIAG", "CRPS_FROM_BS",
         "CRPS_FROM_ECDF",
         "QS", "CRPS_FROM_QS",
-        "POD", "POFD", "FAR", "CSI", "ROCSS",
+        "CONT_TBL", "POD", "POFD", "FAR", "CSI", "ROCSS",
         "RANK_HIST", "DS", "AS",
         "CR", "AW", "AWN", "WS",
         "ES"
@@ -44,7 +44,7 @@ std::tuple<xt::xtensor<double, 1>, xt::xtensor<double, 2>> load_data_p()
     // read in data
     std::ifstream ifs;
     ifs.open(EVALHYD_DATA_DIR "/data/q_obs.csv");
-    xt::xtensor<double, 1> observed = xt::squeeze(xt::load_csv<int>(ifs));
+    xt::xtensor<double, 1> observed = xt::squeeze(xt::load_csv<double>(ifs));
     ifs.close();
 
     ifs.open(EVALHYD_DATA_DIR "/data/q_prd.csv");
@@ -192,7 +192,7 @@ TEST(ProbabilistTests, TestContingency)
 
     // compute scores
     xt::xtensor<double, 2> thresholds = {{690, 534, 445, NAN}};
-    std::vector<std::string> metrics = {"POD", "POFD", "FAR", "CSI", "ROCSS"};
+    std::vector<std::string> metrics = {"CONT_TBL", "POD", "POFD", "FAR", "CSI", "ROCSS"};
 
     std::vector<xt::xarray<double>> results =
             evalhyd::evalp(
@@ -208,8 +208,18 @@ TEST(ProbabilistTests, TestContingency)
     // check results
     for (std::size_t m = 0; m < metrics.size(); m++)
     {
+        if (metrics[m] == "CONT_TBL")
+        {
+            // /!\ stacked-up thresholds and cells in CSV file because 7D metric,
+            //     so need to resize array accordingly
+            expected[metrics[m]].resize(
+                {std::size_t {1}, std::size_t {1}, std::size_t {1}, std::size_t {1},
+                 predicted.shape(0) + 1, thresholds.shape(1), std::size_t {4}}
+            );
+        }
+
         EXPECT_TRUE(xt::all(xt::isclose(
-                results[m], expected[metrics[m]], 1e-05, 1e-08, true
+                results[m], expected[metrics[m]], 1e-04, 1e-07, true
         ))) << "Failure for (" << metrics[m] << ")";
     }
 }
